import os

from ews_core_config import EWSSettings


def test_config():
    settings = EWSSettings.get_settings()
    envs = {k: v for k, v in os.environ.items() if k.startswith("EWS_")}
    assert envs


def test_user_file_read():
    settings = EWSSettings.get_settings()
    assert EWSSettings.sharepoint_username != ""



import logging
import os
from pathlib import Path

import tomlkit
from simple_toml_configurator import Configuration

logger = logging.getLogger(__name__)

default_config = {
    "sharepoint": {
        "server": "ewsconsulting.sharepoint.com",
        "site": "https://ewsconsulting.sharepoint.com/sites/teams_mb/",
        "username": "",
        "password": "",
    },
    "github": {
        "username": "",
        "token": "",
    },
    "ewstools": {
        "url": "",
        "host": "",
        "port": "",
        "username": "",
        "password": "",
    },
    "paths": {
        "mount_point": "/mnt/ews_drives",
        "drives": "f;p;r",
        "mappings": "/smuffile001/daten$:f;/smuffile001/qm$:p;/smuffile001/ROHDATEN$:r",
    },
}


class EWSConfiguration(Configuration):
    def __init__(self) -> None:
        config_path = os.environ.get("EWS_CONFIG_PATH", Path.home())
        config_file_name = os.environ.get("EWS_CONFIG_FILENAME", ".ews_config")
        filename = Path(config_path) / f"{config_file_name}.toml"
        existing = {}
        if filename.is_file():
            logger.debug("Reading defaults from existing file")
            existing = tomlkit.loads(filename.read_bytes())
            existing = {**existing, **default_config}
        else:
            logger.debug("Creating new file")  # pragma: no cover

        super().__init__(
            config_path=config_path,
            config_file_name=config_file_name,
            defaults=existing,
            env_prefix="EWS",
        )


EWSSettings = EWSConfiguration()

__all__ = ("EWSSettings",)



__all__ = ("VERSION", "version_info")

VERSION = "24.2.6.1"


def version_info() -> str:
    """
    Show the version info

    Example:
        ```python
        import ews_core_config

        print(ews_core_config.version_info())
        ```

    """
    import platform
    import sys
    from importlib import import_module  # noqa: F401
    from pathlib import Path

    optional_deps = []

    info = {
        "ews_core_config version": VERSION,
        "install path": Path(__file__).resolve().parent,
        "python version": sys.version,
        "platform": platform.platform(),
        "optional deps. installed": optional_deps,
    }
    return "\n".join("{:>30} {}".format(k + ":", str(v).replace("\n", " ")) for k, v in info.items())



"""
Test suite for the module [ews_env.version](site:api/ews_env/version).
"""

import re

import ews_core_config
from packaging.version import (
    parse as parse_version,  # pyright: ignore [reportMissingImports]
)


def test_version_info():
    """Test the version_info"""
    s = ews_core_config.version_info()
    assert re.match(" *ews_core_config version: ", s)
    assert s.count("\n") == 4


def test_standard_version():
    """Test the standard version"""
    v = parse_version(ews_core_config.VERSION)
    assert str(v) == ews_core_config.VERSION


def test_version_attribute_is_present():
    """Test that __version__ is present"""
    assert hasattr(ews_core_config, "__version__")


def test_version_attribute_is_a_string():
    """Test that __version__ is a string"""
    assert isinstance(ews_core_config.__version__, str)
